@@ -17,7 +17,7 @@ loadCoordWR <- function(unit = c("country", "nato", "ocde", "continent", "region
   nn <- paste("world_",unit,"_", res,sep = "")
 
 
-
+  download <- TRUE
   if(use_cache)
   {
     fl <- list.files(tempdir())
@@ -45,7 +45,7 @@ if(download){
 
     if(internet | use_internet)
     {
-      url <- paste("https://raw.githubusercontent.com/dataallaround/geospatial/master/world/GeoJSON/", file, sep = "")
+      url <- paste("https://raw.githubusercontent.com/mappinguniverse/geospatial/master/world/GeoJSON/", file, sep = "")
       response <- FALSE
 
       if(!response)
@@ -67,7 +67,6 @@ if(download){
 
 
   coord <- st_transform(coord, crs = crs)
-  # coord <- suppressMessages(suppressWarnings((st_buffer(coord,0))))
   coord <- st_make_valid(coord)
   class(coord) <- c(class(coord),"WR")
   attributes(coord)$unit <- unit
@@ -123,7 +122,7 @@ checkNamesWR <- function(id,
 
   nomatch <- setdiff(x = id, y = Wr)
 
-  ## NON FUNZIONE. SISTEMARE!!!!!!!!!!!!!!!1
+  ## NON FUNZIONA SISTEMARE!!!!!!!!!!!!!!!1
 
   # if(any(nomatch))
   # {
@@ -294,10 +293,7 @@ WR <- function(data, colID = NULL,
                          by = list(var = out[, aggregation_unit, drop = TRUE]), FUN = aggregation_fun)
         colnames(out)[1] <- aggregation_unit
         facets_join <- NULL
-        # out[,aggregation_unit] <- tolower(out[,aggregation_unit, drop = TRUE])
-        # nm[,aggregation_unit] <- as.character(tolower(nm[,aggregation_unit, drop = TRUE]))
-        # out[,aggregation_unit] = as.character(out[,aggregation_unit, drop = TRUE])
-        # out <- suppressWarnings(left_join(out, nm,aggregation_unit))
+
         }else{
 
 
@@ -360,14 +356,12 @@ WR <- function(data, colID = NULL,
 
       colID <- aggregation_unit
       colName <- aggregation_unit
-      # attributes(data)$unit <- unit
-      # attributes(data)$colID <- colID
 
     }else{
 
       if(isFALSE(show_wr))
       {
-        #out <- suppressMessages(left_join(coord, out[,-ncol(out), drop = TRUE]))
+        
         out <- out[out[,colName, drop = TRUE] %in% data[,colName],]
 
       }else{
@@ -379,7 +373,6 @@ WR <- function(data, colID = NULL,
 
   class(out) <- c(class(out),"WR")
   attributes(out)$unit <- unit
-  #attributes(out)$year <- year
   attributes(out)$colID <- colName
 
   return(out)
